@@ -65,7 +65,7 @@ around new => sub ( $orig, $self, $args ) {
             }
 
             while ( my $req = shift $dns_req_cache->{ $args->{host} }->@* ) {
-                $args->{cb}->($server);
+                $req->{cb}->($server);
             }
 
             delete $dns_req_cache->{ $args->{host} };
